Documentation
¶
Index ¶
Constants ¶
const CountLookback lookback = "CountLookback"
const TimedeltaLookback lookback = "TimedeltaLookback"
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Node ¶
type Node struct {
// contains filtered or unexported fields
}
Node represents an algorithm in the DAG
func (Node) LenAlgoDeps ¶
type Plan ¶
Plan represents the full execution plan: a sequence of stages
func BuildPlan ¶
func BuildPlan( algoExecPaths []string, windowExecPaths []string, procExecPaths []string, lookbackCounts []string, lookbackTimedeltas []string, targetWindowId int64, ) (Plan, error)
BuildPlan builds a parallel execution Plan from the DAG represented by algoExecPaths, windowExecPaths, and procExecPaths.
type ProcessorTask ¶
ProcessorTask represents a set of tasks (nodes) assigned to a single processor
type Stage ¶
type Stage struct {
Tasks []ProcessorTask
}
Stage represents a set of processor tasks that can be executed in parallel
Click to show internal directories.
Click to hide internal directories.